@@ -1,9 +1,10 @@
-#!/usr/bin/python
+#!/usr/bin/python3
 
 import grp
+import io
 import os
 import pwd
-from test import test_support
+from test.support import EnvironmentVarGuard, run_unittest
 import unittest
 
 # These tests require Mock 0.7.0
@@ -11,42 +12,44 @@ import mock
 
 from ubiquity import misc
 
+
 _proc_swaps = [
     'Filename\t\t\t\tType\t\tSize\tUsed\tPriority',
     '/dev/sda5                               partition\t1046524\t56160\t-1']
 _disk_info = ('Ubuntu-Server 10.04.1 LTS _Lucid Lynx_ '
               '- Release i386 (20100816.2)')
 _proc_mounts = [
-'rootfs / rootfs rw 0 0',
-'none /sys sysfs rw,nosuid,nodev,noexec,relatime 0 0',
-'none /proc proc rw,nosuid,nodev,noexec,relatime 0 0',
-'none /dev devtmpfs rw,relatime,size=503688k,nr_inodes=125922,mode=755 0 0',
-'none /dev/pts devpts rw,nosuid,noexec,relatime,gid=5,mode=620,'
-    'ptmxmode=000 0 0',
-'fusectl /sys/fs/fuse/connections fusectl rw,relatime 0 0',
-'/dev/disk/by-uuid/35583897-668f-4303-80a1-aa4e7f599978 / ext4 '
-    'rw,relatime,errors=remount-ro,barrier=1,data=ordered 0 0',
-'none /sys/kernel/debug debugfs rw,relatime 0 0',
-'none /sys/kernel/security securityfs rw,relatime 0 0',
-'none /dev/shm tmpfs rw,nosuid,nodev,relatime 0 0',
-'none /var/run tmpfs rw,nosuid,relatime,mode=755 0 0',
-'none /var/lock tmpfs rw,nosuid,nodev,noexec,relatime 0 0',
-'binfmt_misc /proc/sys/fs/binfmt_misc binfmt_misc '
-    'rw,nosuid,nodev,noexec,relatime 0 0',
-'gvfs-fuse-daemon /home/evan/.gvfs fuse.gvfs-fuse-daemon '
-    'rw,nosuid,nodev,relatime,user_id=1000,group_id=1000 0 0',
+    'rootfs / rootfs rw 0 0',
+    'none /sys sysfs rw,nosuid,nodev,noexec,relatime 0 0',
+    'none /proc proc rw,nosuid,nodev,noexec,relatime 0 0',
+    ('none /dev devtmpfs '
+     'rw,relatime,size=503688k,nr_inodes=125922,mode=755 0 0'),
+    ('none /dev/pts devpts rw,nosuid,noexec,relatime,gid=5,mode=620,'
+     'ptmxmode=000 0 0'),
+    'fusectl /sys/fs/fuse/connections fusectl rw,relatime 0 0',
+    ('/dev/disk/by-uuid/35583897-668f-4303-80a1-aa4e7f599978 / ext4 '
+     'rw,relatime,errors=remount-ro,barrier=1,data=ordered 0 0'),
+    'none /sys/kernel/debug debugfs rw,relatime 0 0',
+    'none /sys/kernel/security securityfs rw,relatime 0 0',
+    'none /dev/shm tmpfs rw,nosuid,nodev,relatime 0 0',
+    'none /var/run tmpfs rw,nosuid,relatime,mode=755 0 0',
+    'none /var/lock tmpfs rw,nosuid,nodev,noexec,relatime 0 0',
+    ('binfmt_misc /proc/sys/fs/binfmt_misc binfmt_misc '
+     'rw,nosuid,nodev,noexec,relatime 0 0'),
+    ('gvfs-fuse-daemon /home/evan/.gvfs fuse.gvfs-fuse-daemon '
+     'rw,nosuid,nodev,relatime,user_id=1000,group_id=1000 0 0'),
 ]
 
 
-class EnvironmentVarGuard(test_support.EnvironmentVarGuard):
-    """Stronger version of test_support.EnvironmentVarGuard.
+class EnvironmentVarGuardRestore(EnvironmentVarGuard):
+    """Stronger version of EnvironmentVarGuard.
 
     This class restores os.environ even if something within its context
     manipulates os.environ directly.
     """
 
     def __init__(self):
-        test_support.EnvironmentVarGuard.__init__(self)
+        EnvironmentVarGuard.__init__(self)
         self._environ = self._environ.copy()
 
 
@@ -55,15 +58,16 @@ class MiscTests(unittest.TestCase):
     def setUp(self):
         misc.get_release.release_info = None
 
-    @mock.patch('__builtin__.open')
+    @mock.patch('builtins.open')
     def test_is_swap(self, mock_open):
-        magic = mock.MagicMock(spec=file)
+        magic = mock.MagicMock(spec=io.TextIOBase)
         mock_open.return_value = magic
+        magic.__enter__.return_value = magic
         magic.__iter__.return_value = iter(_proc_swaps)
         self.assertTrue(misc.is_swap('/dev/sda5'))
         self.assertFalse(misc.is_swap('/dev/sda'))
 
-    @mock.patch('__builtin__.open')
+    @mock.patch('builtins.open')
     def test_is_swap_fail(self, mock_open):
         mock_open.side_effect = Exception('Ka-blamo!')
         self.assertFalse(misc.is_swap('/dev/sda5'))
@@ -89,9 +93,9 @@ class MiscTests(unittest.TestCase):
         # os.access, raise an exception as a side effect.
         pass
 
-    @mock.patch('__builtin__.open')
+    @mock.patch('builtins.open')
     def test_get_release(self, mock_open):
-        magic = mock.MagicMock(spec=file)
+        magic = mock.MagicMock(spec=io.TextIOBase)
         magic.__enter__.return_value = magic
         mock_open.return_value = magic
         magic.readline.return_value = _disk_info
@@ -99,14 +103,14 @@ class MiscTests(unittest.TestCase):
         self.assertEqual(release.name, 'Ubuntu-Server')
         self.assertEqual(release.version, '10.04.1 LTS')
 
-    @mock.patch('__builtin__.open')
+    @mock.patch('builtins.open')
     def test_get_release_fail(self, mock_open):
         mock_open.side_effect = Exception('Pow!')
         release = misc.get_release()
         self.assertEqual(release.name, 'Ubuntu')
         self.assertEqual(release.version, '')
 
-    #@mock.patch('__builtin__.os.path.exists')
+    #@mock.patch('os.path.exists')
     #def windows_startup_folder(self, mock_exists):
     #    #mock_exists.return_value = True
     #    locations = [
@@ -123,9 +127,9 @@ class MiscTests(unittest.TestCase):
 
     #    self.assertEqual(misc.windows_startup_folder('/tmp/tmp.XXXXXX'))
 
-    @mock.patch('__builtin__.open')
+    @mock.patch('builtins.open')
     def test_mount_info(self, mock_open):
-        magic = mock.MagicMock(spec=file)
+        magic = mock.MagicMock(spec=io.TextIOBase)
         magic.__enter__.return_value = magic
         mock_open.return_value = magic
         # TODO come up with better mountpoints.
@@ -152,8 +156,8 @@ class MiscTests(unittest.TestCase):
         self.assertEqual(mock_execute.call_count, 1)
         self.assertEqual(mock_execute.call_args[0][0], 'setxkbmap')
         self.assertEqual(mock_set_list.call_count, 1)
-        self.assertEqual(mock_set_list.call_args[0][0],
-            'org.gnome.libgnomekbd.keyboard')
+        self.assertEqual(
+            mock_set_list.call_args[0][0], 'org.gnome.libgnomekbd.keyboard')
         self.assertEqual(mock_set_list.call_args[0][1], 'layouts')
         self.assertEqual('us', mock_set_list.call_args[0][2][0])
         self.assertEqual(len(mock_set_list.call_args[0][2]), 4)
@@ -165,8 +169,8 @@ class MiscTests(unittest.TestCase):
         self.assertEqual(mock_execute.call_count, 1)
         self.assertEqual(mock_execute.call_args[0][0], 'setxkbmap')
         self.assertEqual(mock_set_list.call_count, 1)
-        self.assertEqual(mock_set_list.call_args[0][0],
-            'org.gnome.libgnomekbd.keyboard')
+        self.assertEqual(
+            mock_set_list.call_args[0][0], 'org.gnome.libgnomekbd.keyboard')
         self.assertEqual(mock_set_list.call_args[0][1], 'layouts')
         self.assertEqual('fr\toss', mock_set_list.call_args[0][2][0])
         self.assertEqual(len(mock_set_list.call_args[0][2]), 4)
@@ -178,21 +182,20 @@ class MiscTests(unittest.TestCase):
         self.assertEqual(mock_execute.call_count, 1)
         self.assertEqual(mock_execute.call_args[0][0], 'setxkbmap')
         self.assertEqual(mock_set_list.call_count, 1)
-        self.assertEqual(mock_set_list.call_args[0][0],
-            'org.gnome.libgnomekbd.keyboard')
+        self.assertEqual(
+            mock_set_list.call_args[0][0], 'org.gnome.libgnomekbd.keyboard')
         self.assertEqual(mock_set_list.call_args[0][1], 'layouts')
         self.assertIn('se\tdvorak', mock_set_list.call_args[0][2])
 
     @mock.patch('ubiquity.gsettings.set_list')
     @mock.patch('ubiquity.misc.execute')
-    def test_set_indicator_keymaps_ta(self, mock_execute,
-                                        mock_set_list):
+    def test_set_indicator_keymaps_ta(self, mock_execute, mock_set_list):
         misc.set_indicator_keymaps('ta')
         self.assertEqual(mock_execute.call_count, 1)
         self.assertEqual(mock_execute.call_args[0][0], 'setxkbmap')
         self.assertEqual(mock_set_list.call_count, 1)
-        self.assertEqual(mock_set_list.call_args[0][0],
-            'org.gnome.libgnomekbd.keyboard')
+        self.assertEqual(
+            mock_set_list.call_args[0][0], 'org.gnome.libgnomekbd.keyboard')
         self.assertEqual(mock_set_list.call_args[0][1], 'layouts')
         self.assertEqual('in\ttam', mock_set_list.call_args[0][2][0])
         self.assertEqual(len(mock_set_list.call_args[0][2]), 4)
@@ -205,8 +208,8 @@ class MiscTests(unittest.TestCase):
         self.assertEqual(mock_execute.call_count, 1)
         self.assertEqual(mock_execute.call_args[0][0], 'setxkbmap')
         self.assertEqual(mock_set_list.call_count, 1)
-        self.assertEqual(mock_set_list.call_args[0][0],
-            'org.gnome.libgnomekbd.keyboard')
+        self.assertEqual(
+            mock_set_list.call_args[0][0], 'org.gnome.libgnomekbd.keyboard')
         self.assertEqual(mock_set_list.call_args[0][1], 'layouts')
         self.assertEqual('cn', mock_set_list.call_args[0][2][0])
         self.assertEqual(len(mock_set_list.call_args[0][2]), 1)
@@ -259,7 +262,7 @@ class PrivilegeTests(unittest.TestCase):
     @mock.patch('os.seteuid')
     @mock.patch('os.setgroups')
     def test_drop_privileges(self, *args):
-        with test_support.EnvironmentVarGuard() as env:
+        with EnvironmentVarGuard() as env:
             env['SUDO_UID'] = '1000'
             env['SUDO_GID'] = '1000'
             misc.drop_privileges()
@@ -281,7 +284,7 @@ class PrivilegeTests(unittest.TestCase):
     @mock.patch('os.setreuid')
     def test_drop_all_privileges(self, *args):
         pwd.getpwuid.return_value.pw_dir = 'fakeusr'
-        with EnvironmentVarGuard():
+        with EnvironmentVarGuardRestore():
             os.environ['SUDO_UID'] = '1000'
             os.environ['SUDO_GID'] = '1000'
             misc.drop_all_privileges()
@@ -318,14 +321,15 @@ class GrubDefaultTests(unittest.TestCase):
     """
 
     def setUp(self):
-        for obj in (
+        to_patch = (
             'os.path.realpath',
             'os.path.samefile',
             'ubiquity.misc.boot_device',
             'ubiquity.misc.cdrom_mount_info',
             'ubiquity.misc.grub_device_map',
             'ubiquity.misc.is_removable',
-            ):
+        )
+        for obj in to_patch:
             patcher = mock.patch(obj)
             patcher.start()
             self.addCleanup(patcher.stop)
@@ -394,7 +398,7 @@ class GrubDefaultTests(unittest.TestCase):
         self.devices = [
             ['hd0', 'sda', 'disk-1'],
             ['hd1', 'sdb', 'disk-2'],
-            ]
+        ]
         self.cdrom_mount = ('/dev/sr0', 'vfat')
         self.assertEqual('/dev/sda', misc.grub_default())
 
@@ -404,7 +408,7 @@ class GrubDefaultTests(unittest.TestCase):
         self.devices = [
             ['hd0', 'sda', 'cdrom'],
             ['hd1', 'sdb', 'disk'],
-            ]
+        ]
         self.cdrom_mount = ('/dev/sda', 'vfat')
         self.assertEqual('/dev/sdb', misc.grub_default())
         self.cdrom_mount = ('/dev/disk/by-id/cdrom', 'vfat')
@@ -414,7 +418,7 @@ class GrubDefaultTests(unittest.TestCase):
         self.devices = [
             ['hd0', 'sda', 'usb'],
             ['hd1', 'sdb', 'disk'],
-            ]
+        ]
         self.cdrom_mount = ('/dev/sda', 'iso9660')
         self.removable_devices = ['/dev/sda']
         self.boot_device = None
@@ -424,7 +428,7 @@ class GrubDefaultTests(unittest.TestCase):
         self.devices = [
             ['hd0', 'sda', 'disk'],
             ['hd1', 'sdb', 'usb'],
-            ]
+        ]
         self.cdrom_mount = ('/dev/sdb', 'iso9660')
         self.removable_devices = ['/dev/sdb']
         self.boot_device = None
@@ -434,4 +438,4 @@ class GrubDefaultTests(unittest.TestCase):
 
 
 if __name__ == '__main__':
-    test_support.run_unittest(MiscTests, PrivilegeTests, GrubDefaultTests)
+    run_unittest(MiscTests, PrivilegeTests, GrubDefaultTests)
